@@ -4,7 +4,6 @@ from datetime import datetime
 
 import requests
 from lxml import etree
-#from tensorflow import keras
 from zeep import Client
 
 from .exception import TidyException
@@ -113,11 +112,9 @@ class Adapter:
         else:
             raise TidyException(sr)
 
-
-
     def alterQuery(self, id_session: 'str' = None, name_class: 'str' = None, version: 'str' = '0',
-                       keys: 'dict' = None, query: 'str' = 'generic', param_list=[], action: 'str' = '1',
-                       background: 'boolean' = False) -> 'str , ServiceResponse':
+                   keys: 'dict' = None, query: 'str' = 'generic', param_list=[], action: 'str' = '1',
+                   background: 'boolean' = False) -> 'str , ServiceResponse':
         """
         Esegui una alter query con eventuali parametri
         :param id_session: str Id sessione per cui si effettua il logout, se vale None è utilizzata la sessione di default
@@ -219,7 +216,6 @@ class Adapter:
 
         return sr.message, sr
 
-
     def publish(self, id_session: 'str' = None, name_class: 'str' = None, version: str = '0',
                 component_update_type: str = None, action: 'int' = 1, note: 'str' = None,
                 docs: 'list' = None) -> 'str , ServiceResponse':
@@ -296,7 +292,7 @@ class Adapter:
         request += '<items>'
         request += '<item>'
         request += '<name>{}</name>'.format(name_att)
-        request += '<data>{}</data>'.format(data_att.decode('utf8') if isinstance(data_att, bytes) else data_att )
+        request += '<data>{}</data>'.format(data_att.decode('utf8') if isinstance(data_att, bytes) else data_att)
         request += '<documentRevision>0</documentRevision>'
         request += '</item>'
         request += '</items>'
@@ -499,23 +495,19 @@ class Adapter:
         str_list.append('<{}>'.format(root_name))
         for row in matrix:
             str_list.append('<{}>'.format(row_name))
-            i=0;
+            i = 0;
             for col in row:
-                nn=col_name if isinstance(col_name,str) else col_name[i]
+                nn = col_name if isinstance(col_name, str) else col_name[i]
                 str_list.append('<{}>'.format(nn))
                 str_list.append(str(col))
                 str_list.append('</{}>'.format(nn))
-                i+=1
+                i += 1
             str_list.append('</{}>'.format(row_name))
         str_list.append('</{}>'.format(root_name))
         return ''.join(str_list)
 
-
-
-
-
-
-    def save_tf_model(self, id_session: 'str', name, model, scope_metrics: dict = None, model_description: 'str' = '',
+    def save_tf_model(self, id_session: 'str', name, model_name: str, model_summary: str, model_json: str,
+                      base64Model: str, scope_metrics: dict = None, model_description: 'str' = '',
                       revision_detail: 'str' = '', parameters: 'list' = []) -> 'str, ServiceResponse':
         """
         Salva sulla classe di business tfModel un modello tensorflow con i relativi pesi, eventuali parametri aggiuntivi e metriche per la valutazione
@@ -543,21 +535,17 @@ class Adapter:
         str_list.append('<name>{}</name>'.format(name))
         str_list.append('<modelDescription>{}</modelDescription>'.format(model_description))
         str_list.append('<revisionDetail>{}</revisionDetail>'.format(revision_detail))
-        str_list.append('<type>{}</type>'.format(model.name))
-        str_list.append('<summary><![CDATA[{}]]></summary>'.format(model.summary))
-        str_list.append('<json><![CDATA[{}]]></json>'.format(model.to_json()))
+        str_list.append('<type>{}</type>'.format(model_name))
+        str_list.append('<summary><![CDATA[{}]]></summary>'.format(model_summary))
+        str_list.append('<json><![CDATA[{}]]></json>'.format(model_json()))
         str_list.append('<metrics>')
         if scope_metrics is not None:
-            for scope in scope_metrics:
-                inp = scope_metrics.get(scope)
-                metrics = model.evaluate(inp[0], inp[1], verbose=0)
-                if not isinstance(metrics, list):
-                    metrics = [metrics]
-                for i in range(len(metrics)):
+            for scope, metrics in scope_metrics.items():
+                for type, value in metrics.items():
                     str_list.append('<metric>')
                     str_list.append('<scope>{}</scope>'.format(scope))
-                    str_list.append('<type>{}</type>'.format(model.metrics_names[i]))
-                    str_list.append('<value>{}</value>'.format(metrics[i]))
+                    str_list.append('<type>{}</type>'.format(type));
+                    str_list.append('<value>{}</value>'.format(value));
                     str_list.append('</metric>')
         str_list.append('</metrics>')
         str_list.append('<parameters>')
@@ -575,19 +563,11 @@ class Adapter:
 
         message, sr = self.publish(id_session, TF_MODEL, '0', None, 1, 'from python client', [value])
         if sr.code == '0':
-            name_temp_file = 'temp_' + str(datetime.timestamp(datetime.now())).replace('.', '_') + '.h5'
-            model.save(name_temp_file)
-            try:
-                with open(name_temp_file, "rb") as h5:
-                    encoded_string = base64.b64encode(h5.read()).decode('utf-8')
-                    message, sr1 = self.add_attachment(id_session, TF_MODEL, '0', {'name': name}, 'model_h5',
-                                                       encoded_string)
-                    if sr1.code == '0':
-                        return 'model saved correctly', sr1
-                    else:
-                        raise TidyException(sr1)
-            finally:
-                os.remove(name_temp_file)
+            message, sr1 = self.add_attachment(id_session, TF_MODEL, '0', {'name': name}, 'model_h5', base64Model)
+            if sr1.code == '0':
+                return 'model saved correctly', sr1
+            else:
+                raise TidyException(sr1)
         else:
             raise TidyException(sr)
 
@@ -609,14 +589,7 @@ class Adapter:
 
             data, sr = self.read_attachment(id_session, TF_MODEL, '0', {'name': name}, 'model_h5', revision)
             if sr.code == '0':
-                name_temp_file = 'temp_' + str(datetime.timestamp(datetime.now())).replace('.', '_') + '.h5'
-                try:
-                    with open(name_temp_file, "wb") as h5:
-                        h5.write(base64.b64decode(bytearray(data, 'utf-8')))
-                    #model = keras.models.load_model(name_temp_file)
-                finally:
-                    os.remove(name_temp_file)
-                return model, params
+                return data, params
             else:
                 raise TidyException(sr)
         else:
